@@ -2,7 +2,7 @@
 # Configuration file for using the XML library in GNOME applications
 #
 XML2_LIBDIR="-L${libdir}"
-XML2_LIBS="-lxml2 -lz   -lm "
+XML2_LIBS="-lxml2 -lz -lpthread  -lm "
 XML2_INCLUDEDIR="-I${includedir}/libxml2"
-MODULE_VERSION="xml2-2.5.4"
+MODULE_VERSION="xml2-2.5.11"
 
